function [residual, g1, g2, g3] = maincodea_dynamic(y, x, params, steady_state, it_)
%
% Status : Computes dynamic model for Dynare
%
% Inputs :
%   y         [#dynamic variables by 1] double    vector of endogenous variables in the order stored
%                                                 in M_.lead_lag_incidence; see the Manual
%   x         [nperiods by M_.exo_nbr] double     matrix of exogenous variables (in declaration order)
%                                                 for all simulation periods
%   steady_state  [M_.endo_nbr by 1] double       vector of steady state values
%   params    [M_.param_nbr by 1] double          vector of parameter values in declaration order
%   it_       scalar double                       time period for exogenous variables for which to evaluate the model
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the dynamic model equations in order of 
%                                          declaration of the equations.
%                                          Dynare may prepend auxiliary equations, see M_.aux_vars
%   g1        [M_.endo_nbr by #dynamic variables] double    Jacobian matrix of the dynamic model equations;
%                                                           rows: equations in order of declaration
%                                                           columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%   g2        [M_.endo_nbr by (#dynamic variables)^2] double   Hessian matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%   g3        [M_.endo_nbr by (#dynamic variables)^3] double   Third order derivative matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

%
% Model equations
%

residual = zeros(36, 1);
Z__ = (log(y(25))+y(18)^2/2)/y(18);
Zplus__ = (log(y(58))+y(54)^2/2)/y(54);
G__ = normcdf(Z__-y(18),0,1);
Fp1__ = normcdf(Zplus__,0,1);
Gp1__ = normcdf(Zplus__-y(54),0,1);
GAMMAp1__ = y(58)*(1-Fp1__)+Gp1__;
dFp1__ = normpdf(Zplus__,0,1)/y(58)/y(54);
Phi_x__ = params(15)/2*(y(42)/y(10)-1)^2;
dPhi_x__ = params(15)*(y(42)/y(10)-1);
dPhip_x__ = params(15)*(y(63)/y(42)-1);
ir__ = y(42)/y(10);
irp__ = y(63)/y(42);
rb__ = y(40)/y(24);
T159 = (y(13)-params(32))^2;
T182 = y(36)*y(8)/y(24);
T207 = params(3)*y(56)/y(22)*y(59)/y(29);
T211 = irp__^2;
T213 = 1-Phi_x__-dPhi_x__*ir__+T207*dPhip_x__*T211;
T228 = (y(30)/y(20))^params(12);
T232 = y(30)^params(12);
T233 = y(38)*T232;
T234 = y(20)^(1-params(12));
T240 = y(24)^params(13);
T249 = (1-params(14))*y(44)^(-params(13))+params(14)*y(11);
T258 = y(57)^params(13);
T267 = y(57)^(params(13)-1);
T287 = params(9)*y(8)/y(24)/2;
T306 = params(33)*(y(2)/params(33))^params(16);
T312 = (y(24)/params(34))^(params(17)*(1-params(16)));
T318 = (y(48)/params(36))^((1-params(16))*params(18));
T342 = y(7)/y(12)-params(37)/params(36);
T400 = (1-params(27)^2)^0.5*params(29);
T416 = (1-params(28)^2)^0.5*params(30);
lhs =(y(19)-params(1)*y(1))^(-params(2))-params(1)*params(3)*(y(55)-y(19)*params(1))^(-params(2));
rhs =y(22);
residual(1)= lhs-rhs;
lhs =y(22)*y(23);
rhs =params(4)*y(20)^params(5);
residual(2)= lhs-rhs;
lhs =y(22);
rhs =params(3)*y(21)*y(56)/y(57);
residual(3)= lhs-rhs;
lhs =(1-Fp1__)/(1-GAMMAp1__);
rhs =y(37)*(1-Fp1__-y(58)*params(6)*dFp1__)/(1-y(37)*(GAMMAp1__-Gp1__*params(6)));
residual(4)= lhs-rhs;
lhs =y(37)*(GAMMAp1__-Gp1__*params(6))*y(35);
rhs =y(35)-1;
residual(5)= lhs-rhs;
lhs =y(33)/y(24);
rhs =(y(39)+(1-params(7))*y(29))/y(4);
residual(6)= lhs-rhs;
lhs =y(40)/y(24);
rhs =(1-params(8)*y(31))/y(6);
residual(7)= lhs-rhs;
lhs =y(60)-y(62);
rhs =params(9)*(y(49)-params(32));
residual(8)= lhs-rhs;
lhs =y(34);
rhs =y(29)*y(30)+y(31)*y(32);
residual(9)= lhs-rhs;
lhs =y(35);
rhs =y(34)/y(26);
residual(10)= lhs-rhs;
lhs =y(49);
rhs =y(29)*y(30)/y(34);
residual(11)= lhs-rhs;
lhs =y(36);
rhs =y(33)*y(13)+y(40)*(1-y(13))+params(9)/2*T159;
residual(12)= lhs-rhs;
lhs =y(37);
rhs =y(61)/y(21);
residual(13)= lhs-rhs;
lhs =y(28);
rhs =y(34)-y(26);
residual(14)= lhs-rhs;
lhs =y(41);
rhs =y(34)*y(58)*y(61)/y(28);
residual(15)= lhs-rhs;
lhs =y(26);
rhs =params(10)*y(27)+params(11);
residual(16)= lhs-rhs;
lhs =y(27);
rhs =T182*(1-G__*params(6))-y(2)*y(3)/y(24);
residual(17)= lhs-rhs;
lhs =y(30);
rhs =(1-params(7))*y(5)+y(42)*(1-Phi_x__);
residual(18)= lhs-rhs;
lhs =y(29);
rhs =T213^(-1);
residual(19)= lhs-rhs;
lhs =y(23)/y(39);
rhs =y(30)*(1-params(12))/params(12)/y(20);
residual(20)= lhs-rhs;
lhs =y(23);
rhs =(1-params(12))*y(47)*y(38)*T228;
residual(21)= lhs-rhs;
lhs =y(48);
rhs =T233*T234/y(43);
residual(22)= lhs-rhs;
lhs =y(43);
rhs =T240*T249;
residual(23)= lhs-rhs;
lhs =y(45);
rhs =y(48)*y(22)*y(47)+params(3)*params(14)*y(64)*T258;
residual(24)= lhs-rhs;
lhs =y(46);
rhs =y(22)*y(48)+params(3)*params(14)*y(65)*T267;
residual(25)= lhs-rhs;
lhs =y(44);
rhs =y(24)*params(13)/(params(13)-1)*y(45)/y(46);
residual(26)= lhs-rhs;
lhs =y(24)^(1-params(13));
rhs =params(14)+(1-params(14))*y(44)^(1-params(13));
residual(27)= lhs-rhs;
lhs =y(48);
rhs =y(42)+y(19)+y(50)+T159*T287;
residual(28)= lhs-rhs;
lhs =y(31)*y(32)+y(51);
rhs =y(50)+y(6)*rb__*y(7)-G__*params(6)*T182;
residual(29)= lhs-rhs;
lhs =y(21);
rhs =T306*T312*T318*exp(x(it_, 1));
residual(30)= lhs-rhs;
lhs =y(50);
rhs =(1-params(19))*params(38)+params(19)*y(14)+params(20)*(log(y(12))-log(params(36)))+params(21)*T342+exp(y(52))*x(it_, 2);
residual(31)= lhs-rhs;
lhs =y(51);
rhs =(1-params(22))*params(39)+params(22)*y(15)+(log(y(12))-log(params(36)))*params(23)+T342*params(24)+exp(y(53))*x(it_, 3);
residual(32)= lhs-rhs;
lhs =log(y(38));
rhs =params(25)*log(y(9))+x(it_, 4);
residual(33)= lhs-rhs;
lhs =log(y(54)/params(42));
rhs =params(26)*log(y(18)/params(42))+x(it_, 5);
residual(34)= lhs-rhs;
lhs =y(52);
rhs =(1-params(27))*params(40)+params(27)*y(16)+T400*x(it_, 6);
residual(35)= lhs-rhs;
lhs =y(53);
rhs =(1-params(28))*params(41)+params(28)*y(17)+T416*x(it_, 7);
residual(36)= lhs-rhs;
if nargout >= 2,
  g1 = zeros(36, 72);

  %
  % Jacobian matrix
  %

T40 = normpdf(Zplus__,0,1);
T422 = getPowerDeriv(y(19)-params(1)*y(1),(-params(2)),1);
T424 = getPowerDeriv(y(55)-y(19)*params(1),(-params(2)),1);
T439 = getPowerDeriv(y(30)/y(20),params(12),1);
T470 = getPowerDeriv(T213,(-1),1);
T542 = exp((-((Z__-y(18))*(Z__-y(18))))/2)/2.506628274631;
T543 = 1/y(25)/y(18)*T542;
T551 = 1/y(58)/y(54);
T556 = exp((-(Zplus__*Zplus__))/2)/2.506628274631;
T558 = (-(T551*T556));
T565 = exp((-((Zplus__-y(54))*(Zplus__-y(54))))/2)/2.506628274631;
T566 = T551*T565;
T567 = 1-Fp1__+y(58)*T558+T566;
T660 = 1/y(12);
T666 = 1/y(24);
T729 = (-(params(15)/2*(-y(42))/(y(10)*y(10))*2*(y(42)/y(10)-1)));
T742 = (-(params(15)/2*2*(y(42)/y(10)-1)*1/y(10)));
T842 = T542*((y(18)*2*y(18)/2-(log(y(25))+y(18)^2/2))/(y(18)*y(18))-1);
T858 = (y(54)*2*y(54)/2-(log(y(58))+y(54)^2/2))/(y(54)*y(54));
T860 = (-(T556*T858));
  g1(1,1)=(-params(1))*T422;
  g1(1,19)=T422-params(1)*params(3)*(-params(1))*T424;
  g1(1,55)=(-(params(1)*params(3)*T424));
  g1(1,22)=(-1);
  g1(2,20)=(-(params(4)*getPowerDeriv(y(20),params(5),1)));
  g1(2,22)=y(23);
  g1(2,23)=y(22);
  g1(3,21)=(-(params(3)*y(56)/y(57)));
  g1(3,22)=1;
  g1(3,56)=(-(params(3)*y(21)*1/y(57)));
  g1(3,57)=(-(params(3)*y(21)*(-y(56))/(y(57)*y(57))));
  g1(4,58)=((1-GAMMAp1__)*T558-(1-Fp1__)*(-T567))/((1-GAMMAp1__)*(1-GAMMAp1__))-((1-y(37)*(GAMMAp1__-Gp1__*params(6)))*y(37)*(T558-(params(6)*dFp1__+y(58)*params(6)*(y(58)*T40*Zplus__*(-T551)-T40)/(y(58)*y(58))/y(54)))-y(37)*(1-Fp1__-y(58)*params(6)*dFp1__)*(-(y(37)*(T567-params(6)*T566))))/((1-y(37)*(GAMMAp1__-Gp1__*params(6)))*(1-y(37)*(GAMMAp1__-Gp1__*params(6))));
  g1(4,37)=(-(((1-Fp1__-y(58)*params(6)*dFp1__)*(1-y(37)*(GAMMAp1__-Gp1__*params(6)))-y(37)*(1-Fp1__-y(58)*params(6)*dFp1__)*(-(GAMMAp1__-Gp1__*params(6))))/((1-y(37)*(GAMMAp1__-Gp1__*params(6)))*(1-y(37)*(GAMMAp1__-Gp1__*params(6))))));
  g1(4,54)=((1-GAMMAp1__)*T860-(1-Fp1__)*(-(y(58)*T860+T565*(T858-1))))/((1-GAMMAp1__)*(1-GAMMAp1__))-((1-y(37)*(GAMMAp1__-Gp1__*params(6)))*y(37)*(T860-y(58)*params(6)*(y(54)*T40*Zplus__*(-T858)/y(58)-T40/y(58))/(y(54)*y(54)))-y(37)*(1-Fp1__-y(58)*params(6)*dFp1__)*(-(y(37)*(y(58)*T860+T565*(T858-1)-params(6)*T565*(T858-1)))))/((1-y(37)*(GAMMAp1__-Gp1__*params(6)))*(1-y(37)*(GAMMAp1__-Gp1__*params(6))));
  g1(5,58)=y(35)*y(37)*(T567-params(6)*T566);
  g1(5,35)=y(37)*(GAMMAp1__-Gp1__*params(6))-1;
  g1(5,37)=(GAMMAp1__-Gp1__*params(6))*y(35);
  g1(5,54)=y(35)*y(37)*(y(58)*T860+T565*(T858-1)-params(6)*T565*(T858-1));
  g1(6,24)=(-y(33))/(y(24)*y(24));
  g1(6,4)=(-((-(y(39)+(1-params(7))*y(29)))/(y(4)*y(4))));
  g1(6,29)=(-((1-params(7))/y(4)));
  g1(6,33)=T666;
  g1(6,39)=(-(1/y(4)));
  g1(7,24)=(-y(40))/(y(24)*y(24));
  g1(7,6)=(-((-(1-params(8)*y(31)))/(y(6)*y(6))));
  g1(7,31)=(-((-params(8))/y(6)));
  g1(7,40)=T666;
  g1(8,60)=1;
  g1(8,62)=(-1);
  g1(8,49)=(-params(9));
  g1(9,29)=(-y(30));
  g1(9,30)=(-y(29));
  g1(9,31)=(-y(32));
  g1(9,32)=(-y(31));
  g1(9,34)=1;
  g1(10,26)=(-((-y(34))/(y(26)*y(26))));
  g1(10,34)=(-(1/y(26)));
  g1(10,35)=1;
  g1(11,29)=(-(y(30)/y(34)));
  g1(11,30)=(-(y(29)/y(34)));
  g1(11,34)=(-((-(y(29)*y(30)))/(y(34)*y(34))));
  g1(11,49)=1;
  g1(12,33)=(-y(13));
  g1(12,36)=1;
  g1(12,40)=(-(1-y(13)));
  g1(12,13)=(-(y(33)-y(40)+params(9)/2*2*(y(13)-params(32))));
  g1(13,21)=(-((-y(61))/(y(21)*y(21))));
  g1(13,61)=(-(1/y(21)));
  g1(13,37)=1;
  g1(14,26)=1;
  g1(14,28)=1;
  g1(14,34)=(-1);
  g1(15,58)=(-(y(34)*y(61)/y(28)));
  g1(15,28)=(-((-(y(34)*y(58)*y(61)))/(y(28)*y(28))));
  g1(15,34)=(-(y(58)*y(61)/y(28)));
  g1(15,61)=(-(y(58)*y(34)/y(28)));
  g1(15,41)=1;
  g1(16,26)=1;
  g1(16,27)=(-params(10));
  g1(17,2)=y(3)/y(24);
  g1(17,24)=(-((1-G__*params(6))*(-(y(36)*y(8)))/(y(24)*y(24))-(-(y(2)*y(3)))/(y(24)*y(24))));
  g1(17,25)=(-(T182*(-(params(6)*T543))));
  g1(17,27)=1;
  g1(17,3)=y(2)/y(24);
  g1(17,8)=(-((1-G__*params(6))*y(36)/y(24)));
  g1(17,36)=(-((1-G__*params(6))*y(8)/y(24)));
  g1(17,18)=(-(T182*(-(params(6)*T842))));
  g1(18,5)=(-(1-params(7)));
  g1(18,30)=1;
  g1(18,10)=(-(y(42)*T729));
  g1(18,42)=(-(1-Phi_x__+y(42)*T742));
  g1(19,22)=(-(T211*dPhip_x__*y(59)/y(29)*params(3)*(-y(56))/(y(22)*y(22))*T470));
  g1(19,56)=(-(T470*T211*dPhip_x__*y(59)/y(29)*params(3)*1/y(22)));
  g1(19,29)=1-T470*T211*dPhip_x__*params(3)*y(56)/y(22)*(-y(59))/(y(29)*y(29));
  g1(19,59)=(-(T470*T211*dPhip_x__*params(3)*y(56)/y(22)*1/y(29)));
  g1(19,10)=(-(T470*(T729-(ir__*params(15)*(-y(42))/(y(10)*y(10))+dPhi_x__*(-y(42))/(y(10)*y(10))))));
  g1(19,42)=(-(T470*(T742-(ir__*params(15)*1/y(10)+dPhi_x__*1/y(10))+T211*T207*params(15)*(-y(63))/(y(42)*y(42))+T207*dPhip_x__*(-y(63))/(y(42)*y(42))*2*irp__)));
  g1(19,63)=(-(T470*(T211*T207*params(15)*1/y(42)+T207*dPhip_x__*2*irp__*1/y(42))));
  g1(20,20)=(-((-(y(30)*(1-params(12))/params(12)))/(y(20)*y(20))));
  g1(20,23)=1/y(39);
  g1(20,30)=(-((1-params(12))/params(12)/y(20)));
  g1(20,39)=(-y(23))/(y(39)*y(39));
  g1(21,20)=(-((1-params(12))*y(47)*y(38)*(-y(30))/(y(20)*y(20))*T439));
  g1(21,23)=1;
  g1(21,30)=(-((1-params(12))*y(47)*y(38)*T439*1/y(20)));
  g1(21,38)=(-(T228*(1-params(12))*y(47)));
  g1(21,47)=(-(T228*(1-params(12))*y(38)));
  g1(22,20)=(-(T233*getPowerDeriv(y(20),1-params(12),1)/y(43)));
  g1(22,30)=(-(T234*y(38)*getPowerDeriv(y(30),params(12),1)/y(43)));
  g1(22,38)=(-(T232*T234/y(43)));
  g1(22,43)=(-((-(T233*T234))/(y(43)*y(43))));
  g1(22,48)=1;
  g1(23,24)=(-(T249*getPowerDeriv(y(24),params(13),1)));
  g1(23,11)=(-(T240*params(14)));
  g1(23,43)=1;
  g1(23,44)=(-(T240*(1-params(14))*getPowerDeriv(y(44),(-params(13)),1)));
  g1(24,22)=(-(y(47)*y(48)));
  g1(24,57)=(-(params(3)*params(14)*y(64)*getPowerDeriv(y(57),params(13),1)));
  g1(24,45)=1;
  g1(24,64)=(-(params(3)*params(14)*T258));
  g1(24,47)=(-(y(22)*y(48)));
  g1(24,48)=(-(y(22)*y(47)));
  g1(25,22)=(-y(48));
  g1(25,57)=(-(params(3)*params(14)*y(65)*getPowerDeriv(y(57),params(13)-1,1)));
  g1(25,46)=1;
  g1(25,65)=(-(params(3)*params(14)*T267));
  g1(25,48)=(-y(22));
  g1(26,24)=(-(params(13)/(params(13)-1)*y(45)/y(46)));
  g1(26,44)=1;
  g1(26,45)=(-(y(24)*params(13)/(params(13)-1)*1/y(46)));
  g1(26,46)=(-(y(24)*params(13)/(params(13)-1)*(-y(45))/(y(46)*y(46))));
  g1(27,24)=getPowerDeriv(y(24),1-params(13),1);
  g1(27,44)=(-((1-params(14))*getPowerDeriv(y(44),1-params(13),1)));
  g1(28,19)=(-1);
  g1(28,24)=(-(T159*params(9)*(-y(8))/(y(24)*y(24))/2));
  g1(28,8)=(-(T159*params(9)*T666/2));
  g1(28,42)=(-1);
  g1(28,48)=1;
  g1(28,13)=(-(T287*2*(y(13)-params(32))));
  g1(28,50)=(-1);
  g1(29,24)=(-(y(7)*y(6)*(-y(40))/(y(24)*y(24))-G__*params(6)*(-(y(36)*y(8)))/(y(24)*y(24))));
  g1(29,25)=params(6)*T182*T543;
  g1(29,6)=(-(rb__*y(7)));
  g1(29,31)=y(32);
  g1(29,7)=(-(y(6)*rb__));
  g1(29,32)=y(31);
  g1(29,8)=G__*params(6)*y(36)/y(24);
  g1(29,36)=G__*params(6)*y(8)/y(24);
  g1(29,40)=(-(y(7)*y(6)*T666));
  g1(29,50)=(-1);
  g1(29,51)=1;
  g1(29,18)=params(6)*T182*T842;
  g1(30,2)=(-(exp(x(it_, 1))*T318*T312*params(33)*1/params(33)*getPowerDeriv(y(2)/params(33),params(16),1)));
  g1(30,21)=1;
  g1(30,24)=(-(exp(x(it_, 1))*T318*T306*1/params(34)*getPowerDeriv(y(24)/params(34),params(17)*(1-params(16)),1)));
  g1(30,48)=(-(exp(x(it_, 1))*T306*T312*1/params(36)*getPowerDeriv(y(48)/params(36),(1-params(16))*params(18),1)));
  g1(30,66)=(-(T306*T312*T318*exp(x(it_, 1))));
  g1(31,7)=(-(params(21)*T660));
  g1(31,12)=(-(params(20)*T660+params(21)*(-y(7))/(y(12)*y(12))));
  g1(31,14)=(-params(19));
  g1(31,50)=1;
  g1(31,52)=(-(exp(y(52))*x(it_, 2)));
  g1(31,67)=(-exp(y(52)));
  g1(32,7)=(-(params(24)*T660));
  g1(32,12)=(-(params(23)*T660+params(24)*(-y(7))/(y(12)*y(12))));
  g1(32,15)=(-params(22));
  g1(32,51)=1;
  g1(32,53)=(-(exp(y(53))*x(it_, 3)));
  g1(32,68)=(-exp(y(53)));
  g1(33,9)=(-(params(25)*1/y(9)));
  g1(33,38)=1/y(38);
  g1(33,69)=(-1);
  g1(34,18)=(-(params(26)*1/params(42)/(y(18)/params(42))));
  g1(34,54)=1/params(42)/(y(54)/params(42));
  g1(34,70)=(-1);
  g1(35,16)=(-params(27));
  g1(35,52)=1;
  g1(35,71)=(-T400);
  g1(36,17)=(-params(28));
  g1(36,53)=1;
  g1(36,72)=(-T416);

if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],36,5184);
if nargout >= 4,
  %
  % Third order derivatives
  %

  g3 = sparse([],[],[],36,373248);
end
end
end
end
