function [residual, g1, g2, g3] = maincodea_static(y, x, params)
%
% Status : Computes static model for Dynare
%
% Inputs : 
%   y         [M_.endo_nbr by 1] double    vector of endogenous variables in declaration order
%   x         [M_.exo_nbr by 1] double     vector of exogenous variables in declaration order
%   params    [M_.param_nbr by 1] double   vector of parameter values in declaration order
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the static model equations 
%                                          in order of declaration of the equations.
%                                          Dynare may prepend or append auxiliary equations, see M_.aux_vars
%   g1        [M_.endo_nbr by M_.endo_nbr] double    Jacobian matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%   g2        [M_.endo_nbr by (M_.endo_nbr)^2] double   Hessian matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%   g3        [M_.endo_nbr by (M_.endo_nbr)^3] double   Third derivatives matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

residual = zeros( 36, 1);

%
% Model equations
%

Z__ = (log(y(7))+y(36)^2/2)/y(36);
Zplus__ = (log(y(7))+y(36)^2/2)/y(36);
G__ = normcdf(Z__-y(36),0,1);
Fp1__ = normcdf(Zplus__,0,1);
Gp1__ = normcdf(Zplus__-y(36),0,1);
GAMMAp1__ = y(7)*(1-Fp1__)+Gp1__;
dFp1__ = normpdf(Zplus__,0,1)/y(7)/y(36);
Phi_x__ = 0;
dPhi_x__ = 0;
dPhip_x__ = 0;
ir__ = 1;
irp__ = 1;
rb__ = y(22)/y(6);
T48 = (y(1)-y(1)*params(1))^(-params(2));
T129 = (y(31)-params(32))^2;
T150 = y(16)*y(18)/y(6);
T188 = (y(12)/y(2))^params(12);
T192 = y(12)^params(12);
T193 = y(20)*T192;
T194 = y(2)^(1-params(12));
T200 = y(6)^params(13);
T208 = (1-params(14))*y(26)^(-params(13))+y(25)*params(14);
T223 = y(6)^(params(13)-1);
T243 = params(9)*y(16)/y(6)/2;
T261 = params(33)*(y(3)/params(33))^params(16);
T267 = (y(6)/params(34))^(params(17)*(1-params(16)));
T273 = (y(30)/params(36))^((1-params(16))*params(18));
T295 = y(14)/y(30)-params(37)/params(36);
lhs =T48-T48*params(1)*params(3);
rhs =y(4);
residual(1)= lhs-rhs;
lhs =y(4)*y(5);
rhs =params(4)*y(2)^params(5);
residual(2)= lhs-rhs;
lhs =y(4);
rhs =params(3)*y(3)*y(4)/y(6);
residual(3)= lhs-rhs;
lhs =(1-Fp1__)/(1-GAMMAp1__);
rhs =y(19)*(1-Fp1__-y(7)*params(6)*dFp1__)/(1-y(19)*(GAMMAp1__-Gp1__*params(6)));
residual(4)= lhs-rhs;
lhs =y(19)*(GAMMAp1__-Gp1__*params(6))*y(17);
rhs =y(17)-1;
residual(5)= lhs-rhs;
lhs =y(15)/y(6);
rhs =(y(21)+(1-params(7))*y(11))/y(11);
residual(6)= lhs-rhs;
lhs =y(22)/y(6);
rhs =(1-params(8)*y(13))/y(13);
residual(7)= lhs-rhs;
lhs =y(15)-y(22);
rhs =params(9)*(y(31)-params(32));
residual(8)= lhs-rhs;
lhs =y(16);
rhs =y(11)*y(12)+y(13)*y(14);
residual(9)= lhs-rhs;
lhs =y(17);
rhs =y(16)/y(8);
residual(10)= lhs-rhs;
lhs =y(31);
rhs =y(11)*y(12)/y(16);
residual(11)= lhs-rhs;
lhs =y(18);
rhs =y(15)*y(31)+y(22)*(1-y(31))+params(9)/2*T129;
residual(12)= lhs-rhs;
lhs =y(19);
rhs =y(18)/y(3);
residual(13)= lhs-rhs;
lhs =y(10);
rhs =y(16)-y(8);
residual(14)= lhs-rhs;
lhs =y(23);
rhs =y(16)*y(7)*y(18)/y(10);
residual(15)= lhs-rhs;
lhs =y(8);
rhs =params(10)*y(9)+params(11);
residual(16)= lhs-rhs;
lhs =y(9);
rhs =T150*(1-G__*params(6))-y(3)*y(10)/y(6);
residual(17)= lhs-rhs;
lhs =y(12);
rhs =(1-params(7))*y(12)+y(24)*(1-Phi_x__);
residual(18)= lhs-rhs;
lhs =y(11);
rhs =(1-Phi_x__-dPhi_x__*ir__+params(3)*dPhip_x__*irp__^2)^(-1);
residual(19)= lhs-rhs;
lhs =y(5)/y(21);
rhs =y(12)*(1-params(12))/params(12)/y(2);
residual(20)= lhs-rhs;
lhs =y(5);
rhs =(1-params(12))*y(29)*y(20)*T188;
residual(21)= lhs-rhs;
lhs =y(30);
rhs =T193*T194/y(25);
residual(22)= lhs-rhs;
lhs =y(25);
rhs =T200*T208;
residual(23)= lhs-rhs;
lhs =y(27);
rhs =y(30)*y(4)*y(29)+T200*y(27)*params(3)*params(14);
residual(24)= lhs-rhs;
lhs =y(28);
rhs =y(4)*y(30)+params(3)*params(14)*y(28)*T223;
residual(25)= lhs-rhs;
lhs =y(26);
rhs =y(6)*params(13)/(params(13)-1)*y(27)/y(28);
residual(26)= lhs-rhs;
lhs =y(6)^(1-params(13));
rhs =params(14)+(1-params(14))*y(26)^(1-params(13));
residual(27)= lhs-rhs;
lhs =y(30);
rhs =y(24)+y(1)+y(32)+T129*T243;
residual(28)= lhs-rhs;
lhs =y(13)*y(14)+y(33);
rhs =y(32)+y(14)*y(13)*rb__-G__*params(6)*T150;
residual(29)= lhs-rhs;
lhs =y(3);
rhs =T261*T267*T273*exp(x(1));
residual(30)= lhs-rhs;
lhs =y(32);
rhs =(1-params(19))*params(38)+y(32)*params(19)+params(20)*(log(y(30))-log(params(36)))+params(21)*T295+exp(y(34))*x(2);
residual(31)= lhs-rhs;
lhs =y(33);
rhs =(1-params(22))*params(39)+y(33)*params(22)+(log(y(30))-log(params(36)))*params(23)+T295*params(24)+exp(y(35))*x(3);
residual(32)= lhs-rhs;
lhs =log(y(20));
rhs =log(y(20))*params(25)+x(4);
residual(33)= lhs-rhs;
lhs =log(y(36)/params(42));
rhs =log(y(36)/params(42))*params(26)+x(5);
residual(34)= lhs-rhs;
lhs =y(34);
rhs =(1-params(27))*params(40)+y(34)*params(27)+(1-params(27)^2)^0.5*params(29)*x(6);
residual(35)= lhs-rhs;
lhs =y(35);
rhs =(1-params(28))*params(41)+y(35)*params(28)+(1-params(28)^2)^0.5*params(30)*x(7);
residual(36)= lhs-rhs;
if ~isreal(residual)
  residual = real(residual)+imag(residual).^2;
end
if nargout >= 2,
  g1 = zeros(36, 36);

  %
  % Jacobian matrix
  %

T33 = normpdf(Zplus__,0,1);
T369 = (1-params(1))*getPowerDeriv(y(1)-y(1)*params(1),(-params(2)),1);
T381 = getPowerDeriv(y(12)/y(2),params(12),1);
T405 = 1/y(6);
T428 = getPowerDeriv(y(6),params(13),1);
T459 = 1/y(7)/y(36);
T466 = exp((-(Zplus__*Zplus__))/2)/2.506628274631;
T468 = (-(T459*T466));
T475 = exp((-((Zplus__-y(36))*(Zplus__-y(36))))/2)/2.506628274631;
T476 = T459*T475;
T477 = 1-Fp1__+y(7)*T468+T476;
T514 = exp((-((Z__-y(36))*(Z__-y(36))))/2)/2.506628274631;
T564 = 1/y(30);
T685 = (y(36)*2*y(36)/2-(log(y(7))+y(36)^2/2))/(y(36)*y(36));
T687 = (-(T466*T685));
T725 = 1/params(42)/(y(36)/params(42));
  g1(1,1)=T369-params(1)*params(3)*T369;
  g1(1,4)=(-1);
  g1(2,2)=(-(params(4)*getPowerDeriv(y(2),params(5),1)));
  g1(2,4)=y(5);
  g1(2,5)=y(4);
  g1(3,3)=(-(params(3)*y(4)/y(6)));
  g1(3,4)=1-params(3)*y(3)*T405;
  g1(3,6)=(-(params(3)*y(3)*(-y(4))/(y(6)*y(6))));
  g1(4,7)=((1-GAMMAp1__)*T468-(1-Fp1__)*(-T477))/((1-GAMMAp1__)*(1-GAMMAp1__))-((1-y(19)*(GAMMAp1__-Gp1__*params(6)))*y(19)*(T468-(params(6)*dFp1__+y(7)*params(6)*(y(7)*T33*Zplus__*(-T459)-T33)/(y(7)*y(7))/y(36)))-y(19)*(1-Fp1__-y(7)*params(6)*dFp1__)*(-(y(19)*(T477-params(6)*T476))))/((1-y(19)*(GAMMAp1__-Gp1__*params(6)))*(1-y(19)*(GAMMAp1__-Gp1__*params(6))));
  g1(4,19)=(-(((1-Fp1__-y(7)*params(6)*dFp1__)*(1-y(19)*(GAMMAp1__-Gp1__*params(6)))-y(19)*(1-Fp1__-y(7)*params(6)*dFp1__)*(-(GAMMAp1__-Gp1__*params(6))))/((1-y(19)*(GAMMAp1__-Gp1__*params(6)))*(1-y(19)*(GAMMAp1__-Gp1__*params(6))))));
  g1(4,36)=((1-GAMMAp1__)*T687-(1-Fp1__)*(-(y(7)*T687+T475*(T685-1))))/((1-GAMMAp1__)*(1-GAMMAp1__))-((1-y(19)*(GAMMAp1__-Gp1__*params(6)))*y(19)*(T687-y(7)*params(6)*(y(36)*T33*Zplus__*(-T685)/y(7)-T33/y(7))/(y(36)*y(36)))-y(19)*(1-Fp1__-y(7)*params(6)*dFp1__)*(-(y(19)*(y(7)*T687+T475*(T685-1)-params(6)*T475*(T685-1)))))/((1-y(19)*(GAMMAp1__-Gp1__*params(6)))*(1-y(19)*(GAMMAp1__-Gp1__*params(6))));
  g1(5,7)=y(17)*y(19)*(T477-params(6)*T476);
  g1(5,17)=y(19)*(GAMMAp1__-Gp1__*params(6))-1;
  g1(5,19)=(GAMMAp1__-Gp1__*params(6))*y(17);
  g1(5,36)=y(17)*y(19)*(y(7)*T687+T475*(T685-1)-params(6)*T475*(T685-1));
  g1(6,6)=(-y(15))/(y(6)*y(6));
  g1(6,11)=(-(((1-params(7))*y(11)-(y(21)+(1-params(7))*y(11)))/(y(11)*y(11))));
  g1(6,15)=T405;
  g1(6,21)=(-(1/y(11)));
  g1(7,6)=(-y(22))/(y(6)*y(6));
  g1(7,13)=(-((y(13)*(-params(8))-(1-params(8)*y(13)))/(y(13)*y(13))));
  g1(7,22)=T405;
  g1(8,15)=1;
  g1(8,22)=(-1);
  g1(8,31)=(-params(9));
  g1(9,11)=(-y(12));
  g1(9,12)=(-y(11));
  g1(9,13)=(-y(14));
  g1(9,14)=(-y(13));
  g1(9,16)=1;
  g1(10,8)=(-((-y(16))/(y(8)*y(8))));
  g1(10,16)=(-(1/y(8)));
  g1(10,17)=1;
  g1(11,11)=(-(y(12)/y(16)));
  g1(11,12)=(-(y(11)/y(16)));
  g1(11,16)=(-((-(y(11)*y(12)))/(y(16)*y(16))));
  g1(11,31)=1;
  g1(12,15)=(-y(31));
  g1(12,18)=1;
  g1(12,22)=(-(1-y(31)));
  g1(12,31)=(-(y(15)-y(22)+params(9)/2*2*(y(31)-params(32))));
  g1(13,3)=(-((-y(18))/(y(3)*y(3))));
  g1(13,18)=(-(1/y(3)));
  g1(13,19)=1;
  g1(14,8)=1;
  g1(14,10)=1;
  g1(14,16)=(-1);
  g1(15,7)=(-(y(16)*y(18)/y(10)));
  g1(15,10)=(-((-(y(16)*y(7)*y(18)))/(y(10)*y(10))));
  g1(15,16)=(-(y(7)*y(18)/y(10)));
  g1(15,18)=(-(y(7)*y(16)/y(10)));
  g1(15,23)=1;
  g1(16,8)=1;
  g1(16,9)=(-params(10));
  g1(17,3)=y(10)/y(6);
  g1(17,6)=(-((1-G__*params(6))*(-(y(16)*y(18)))/(y(6)*y(6))-(-(y(3)*y(10)))/(y(6)*y(6))));
  g1(17,7)=(-(T150*(-(params(6)*T459*T514))));
  g1(17,9)=1;
  g1(17,10)=y(3)/y(6);
  g1(17,16)=(-((1-G__*params(6))*y(18)/y(6)));
  g1(17,18)=(-((1-G__*params(6))*y(16)/y(6)));
  g1(17,36)=(-(T150*(-(params(6)*T514*(T685-1)))));
  g1(18,12)=1-(1-params(7));
  g1(18,24)=(-(1-Phi_x__));
  g1(19,11)=1;
  g1(20,2)=(-((-(y(12)*(1-params(12))/params(12)))/(y(2)*y(2))));
  g1(20,5)=1/y(21);
  g1(20,12)=(-((1-params(12))/params(12)/y(2)));
  g1(20,21)=(-y(5))/(y(21)*y(21));
  g1(21,2)=(-((1-params(12))*y(29)*y(20)*(-y(12))/(y(2)*y(2))*T381));
  g1(21,5)=1;
  g1(21,12)=(-((1-params(12))*y(29)*y(20)*T381*1/y(2)));
  g1(21,20)=(-(T188*(1-params(12))*y(29)));
  g1(21,29)=(-(T188*(1-params(12))*y(20)));
  g1(22,2)=(-(T193*getPowerDeriv(y(2),1-params(12),1)/y(25)));
  g1(22,12)=(-(T194*y(20)*getPowerDeriv(y(12),params(12),1)/y(25)));
  g1(22,20)=(-(T192*T194/y(25)));
  g1(22,25)=(-((-(T193*T194))/(y(25)*y(25))));
  g1(22,30)=1;
  g1(23,6)=(-(T208*T428));
  g1(23,25)=1-T200*params(14);
  g1(23,26)=(-(T200*(1-params(14))*getPowerDeriv(y(26),(-params(13)),1)));
  g1(24,4)=(-(y(29)*y(30)));
  g1(24,6)=(-(y(27)*params(3)*params(14)*T428));
  g1(24,27)=1-T200*params(3)*params(14);
  g1(24,29)=(-(y(4)*y(30)));
  g1(24,30)=(-(y(4)*y(29)));
  g1(25,4)=(-y(30));
  g1(25,6)=(-(params(3)*params(14)*y(28)*getPowerDeriv(y(6),params(13)-1,1)));
  g1(25,28)=1-params(3)*params(14)*T223;
  g1(25,30)=(-y(4));
  g1(26,6)=(-(params(13)/(params(13)-1)*y(27)/y(28)));
  g1(26,26)=1;
  g1(26,27)=(-(y(6)*params(13)/(params(13)-1)*1/y(28)));
  g1(26,28)=(-(y(6)*params(13)/(params(13)-1)*(-y(27))/(y(28)*y(28))));
  g1(27,6)=getPowerDeriv(y(6),1-params(13),1);
  g1(27,26)=(-((1-params(14))*getPowerDeriv(y(26),1-params(13),1)));
  g1(28,1)=(-1);
  g1(28,6)=(-(T129*params(9)*(-y(16))/(y(6)*y(6))/2));
  g1(28,16)=(-(T129*params(9)*T405/2));
  g1(28,24)=(-1);
  g1(28,30)=1;
  g1(28,31)=(-(T243*2*(y(31)-params(32))));
  g1(28,32)=(-1);
  g1(29,6)=(-(y(14)*y(13)*(-y(22))/(y(6)*y(6))-G__*params(6)*(-(y(16)*y(18)))/(y(6)*y(6))));
  g1(29,7)=params(6)*T150*T459*T514;
  g1(29,13)=y(14)-y(14)*rb__;
  g1(29,14)=y(13)-y(13)*rb__;
  g1(29,16)=G__*params(6)*y(18)/y(6);
  g1(29,18)=G__*params(6)*y(16)/y(6);
  g1(29,22)=(-(y(14)*y(13)*T405));
  g1(29,32)=(-1);
  g1(29,33)=1;
  g1(29,36)=params(6)*T150*T514*(T685-1);
  g1(30,3)=1-exp(x(1))*T273*T267*params(33)*1/params(33)*getPowerDeriv(y(3)/params(33),params(16),1);
  g1(30,6)=(-(exp(x(1))*T273*T261*1/params(34)*getPowerDeriv(y(6)/params(34),params(17)*(1-params(16)),1)));
  g1(30,30)=(-(exp(x(1))*T261*T267*1/params(36)*getPowerDeriv(y(30)/params(36),(1-params(16))*params(18),1)));
  g1(31,14)=(-(params(21)*T564));
  g1(31,30)=(-(params(20)*T564+params(21)*(-y(14))/(y(30)*y(30))));
  g1(31,32)=1-params(19);
  g1(31,34)=(-(exp(y(34))*x(2)));
  g1(32,14)=(-(params(24)*T564));
  g1(32,30)=(-(params(23)*T564+params(24)*(-y(14))/(y(30)*y(30))));
  g1(32,33)=1-params(22);
  g1(32,35)=(-(exp(y(35))*x(3)));
  g1(33,20)=1/y(20)-params(25)*1/y(20);
  g1(34,36)=T725-params(26)*T725;
  g1(35,34)=1-params(27);
  g1(36,35)=1-params(28);
  if ~isreal(g1)
    g1 = real(g1)+2*imag(g1);
  end
if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],36,1296);
if nargout >= 4,
  %
  % Third order derivatives
  %

  g3 = sparse([],[],[],36,46656);
end
end
end
end
